<?php
namespace PDFLink\Site\BlockLayout;

use Omeka\Api\Representation\SiteRepresentation;
use Omeka\Api\Representation\SitePageRepresentation;
use Omeka\Api\Representation\SitePageBlockRepresentation;
use Omeka\Site\BlockLayout\AbstractBlockLayout;
use Laminas\View\Renderer\PhpRenderer;

use Laminas\Form\FormElementManager;

use PDFLink\Form\PDFLinkBlockForm;

class PDFLink extends AbstractBlockLayout
{
	/**
     * @var FormElementManager
     */
    protected $formElementManager;

    /**
     * @var array
     */
	protected $defaultSettings = [];

    /**
     * @param FormElementManager $formElementManager
     * @param array $defaultSettings
     */
    public function __construct(FormElementManager $formElementManager, array $defaultSettings)
    {
        $this->formElementManager = $formElementManager;
        $this->defaultSettings = $defaultSettings;
    }

	public function getLabel() {
		return 'PDF link';
	}

	public function form(PhpRenderer $view,
                       SiteRepresentation $site,
                       SitePageRepresentation $page = null,
                       SitePageBlockRepresentation $block = null
    ) {
		$form = $this->formElementManager->get(PDFLinkBlockForm::class);
		$data = $block
			? $block->data() + $this->defaultSettings
			: $this->defaultSettings;
		$form->setData([
			'o:block[__blockIndex__][o:data][description_text]' => $data['description_text'],
		]);
		$form->prepare();

		$html = '';
		$html .= $view->blockAttachmentsForm($block);
		$html .= '<a href="#" class="collapse" aria-label="collapse"><h4>';
    $html .= $view->translate('Options'). '</h4></a>';
		$html .= '<div class="collapsible" style="padding-top:6px;">';
		$html .= $view->formCollection($form);
    $html .= '</div>';
		return $html;
    }

	public function render(PhpRenderer $view, SitePageBlockRepresentation $block)
	{
		$attachments = $block->attachments();
        if (!$attachments) {
            return '';
		}

		static $id = 0;

    $media = $attachments[0]->item()->media()[0];
		return $view->partial('common/block-layout/pDFLink', [
			'description_text' => $block->dataValue('description_text'),
			'link_name' => $media->displayTitle(),
      'item_url' => $attachments[0]->item()->url(),
			'pdf_url' => $media->originalUrl(),
      'id' => 'pdf-' . ++$id,
		]);
	}
}
